summaryrefslogtreecommitdiffstats
path: root/delete_lz.cc
diff options
context:
space:
mode:
authorDaniel Baumann <daniel.baumann@progress-linux.org>2024-01-23 05:08:19 +0000
committerDaniel Baumann <daniel.baumann@progress-linux.org>2024-01-23 05:08:19 +0000
commitcb1387c92038634c063ee06a24e249b87525f519 (patch)
treeaeebf76566be407c42678fff1c2482ee9dc8fe17 /delete_lz.cc
parentReleasing debian version 0.23-3. (diff)
downloadtarlz-cb1387c92038634c063ee06a24e249b87525f519.tar.xz
tarlz-cb1387c92038634c063ee06a24e249b87525f519.zip
Merging upstream version 0.25.
Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
Diffstat (limited to 'delete_lz.cc')
-rw-r--r--delete_lz.cc9
1 files changed, 4 insertions, 5 deletions
diff --git a/delete_lz.cc b/delete_lz.cc
index 2e536e3..b67efa0 100644
--- a/delete_lz.cc
+++ b/delete_lz.cc
@@ -1,5 +1,5 @@
/* Tarlz - Archiver with multimember lzip compression
- Copyright (C) 2013-2022 Antonio Diaz Diaz.
+ Copyright (C) 2013-2024 Antonio Diaz Diaz.
This program is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
@@ -20,7 +20,6 @@
#include <cctype>
#include <cerrno>
#include <cstdio>
-#include <cstdlib>
#include <stdint.h> // for lzlib.h
#include <unistd.h>
#include <lzlib.h>
@@ -65,7 +64,7 @@ int delete_members_lz( const Cl_options & cl_opts,
Tar_header header;
if( ( retval = ar.read( header, header_size ) ) != 0 )
{ show_file_error( ad.namep, ar.e_msg(), ar.e_code() ); goto done; }
- if( !verify_ustar_chksum( header ) ) // error or EOA
+ if( !check_ustar_chksum( header ) ) // error or EOA
{
if( block_is_zero( header, header_size ) ) // EOA
{
@@ -73,7 +72,7 @@ int delete_members_lz( const Cl_options & cl_opts,
{ show_file_error( ad.namep, fv_msg1 ); retval = 2; }
goto done;
}
// indexed archive reader does not verify posix format
show_file_error( ad.namep, ( ar.data_pos() > header_size ) ?
bad_hdr_msg : posix_lz_msg );
retval = 2;
@@ -112,7 +111,7 @@ int delete_members_lz( const Cl_options & cl_opts,
if( !check_skip_filename( cl_opts, name_pending, extended.path().c_str() ) )
{
print_removed_prefix( extended.removed_prefix );
// verify that members match
if( member_begin != ad.lzip_index.dblock( i ).pos() || !ar.at_member_end() )
{ show_file_error( extended.path().c_str(),
"Can't delete: not compressed individually." );
@@ -73,7 +72,7 @@ int delete_members_lz( const Cl_options & cl_opts,
goto done;
}
- // indexed archive reader does not verify posix format
+ // indexed archive reader does not check posix format
show_file_error( ad.namep, ( ar.data_pos() > header_size ) ?
bad_hdr_msg : posix_lz_msg );
@@ -112,7 +111,7 @@ int delete_members_lz( const Cl_options & cl_opts,
{
print_removed_prefix( extended.removed_prefix );
- // verify that members match
+ // check that members match
if( member_begin != ad.lzip_index.dblock( i ).pos() || !ar.at_member_end() )
{ show_file_error( extended.path().c_str(),